@@ -3,6 +3,7 @@ package analyze
 import (
 	"bytes"
 	"testing"
+	"time"
 
 	log "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
@@ -18,6 +19,7 @@ func TestEncode(t *testing.T) {
 			Name:  "test_dir",
 			Size:  10,
 			Usage: 18,
+			Mtime: time.Date(2021, 8, 19, 0, 40, 0, 0, time.UTC),
 		},
 		ItemCount: 4,
 		BasePath:  ".",
@@ -44,6 +46,7 @@ func TestEncode(t *testing.T) {
 		Usage:  6,
 		Parent: subdir,
 		Flag:   '@',
+		Mtime:  time.Date(2021, 8, 19, 0, 40, 0, 0, time.UTC),
 	}
 	dir.Files = Files{subdir}
 	subdir.Files = Files{file, file2}
@@ -53,4 +56,5 @@ func TestEncode(t *testing.T) {
 
 	assert.Nil(t, err)
 	assert.Contains(t, buff.String(), `"name":"nested"`)
+	assert.Contains(t, buff.String(), `"mtime":1629333600`)
 }
